Index: /trunk/MagicSoft/Mars/Changelog
===================================================================
--- /trunk/MagicSoft/Mars/Changelog	(revision 3619)
+++ /trunk/MagicSoft/Mars/Changelog	(revision 3620)
@@ -37,4 +37,5 @@
    * mcalib/MHCalibrationChargeBlindPix.[h,cc]
    * mcalib/MHCalibrationChargePINDiode.[h,cc]
+   * mcalib/MHCalibrationRelTimePix.[h,cc]
      - updated and enlarged documentation
 
Index: /trunk/MagicSoft/Mars/mcalib/MCalibrationChargeBlindPix.cc
===================================================================
--- /trunk/MagicSoft/Mars/mcalib/MCalibrationChargeBlindPix.cc	(revision 3619)
+++ /trunk/MagicSoft/Mars/mcalib/MCalibrationChargeBlindPix.cc	(revision 3620)
@@ -25,5 +25,5 @@
 /////////////////////////////////////////////////////////////////////////////
 //                                                                         //
-// MCalibrationChargeBlindPix                                                    //
+// MCalibrationChargeBlindPix                                              //
 //                                                                         //
 // This is the storage container to hold informations about the calibration//
Index: /trunk/MagicSoft/Mars/mcalib/MHCalibrationChargePINDiode.cc
===================================================================
--- /trunk/MagicSoft/Mars/mcalib/MHCalibrationChargePINDiode.cc	(revision 3619)
+++ /trunk/MagicSoft/Mars/mcalib/MHCalibrationChargePINDiode.cc	(revision 3620)
@@ -180,5 +180,5 @@
 // Fills the following histograms:
 // - MHGausEvents::FillHistAndArray(signal)
-// - FillAbsTime(time);
+// - MHCalibrationChargePix::FillAbsTime(time);
 // - FillRmsCharge(rms);
 //
Index: /trunk/MagicSoft/Mars/mcalib/MHCalibrationRelTimeCam.cc
===================================================================
--- /trunk/MagicSoft/Mars/mcalib/MHCalibrationRelTimeCam.cc	(revision 3619)
+++ /trunk/MagicSoft/Mars/mcalib/MHCalibrationRelTimeCam.cc	(revision 3620)
@@ -45,5 +45,6 @@
 
 using namespace std;
-const Float_t MHCalibrationRelTimeCam::fgTimeSliceWidth = 3.3;
+const Float_t MHCalibrationRelTimeCam::fgTimeSliceWidth  = 3.3;
+const Int_t   MHCalibrationRelTimeCam::fgPulserFrequency = 500;
 // --------------------------------------------------------------------------
 //
@@ -66,4 +67,5 @@
 
   SetTimeSliceWidth();
+  SetPulserFrequency();
 }
 
@@ -167,4 +169,5 @@
           hist.ChangeHistId(i);
           hist.InitBins();
+          hist.SetEventFrequency(fPulserFrequency);
         }
     }
Index: /trunk/MagicSoft/Mars/mcalib/MHCalibrationRelTimePix.cc
===================================================================
--- /trunk/MagicSoft/Mars/mcalib/MHCalibrationRelTimePix.cc	(revision 3619)
+++ /trunk/MagicSoft/Mars/mcalib/MHCalibrationRelTimePix.cc	(revision 3620)
@@ -27,5 +27,5 @@
 //  MHCalibrationRelTimePix
 //
-//  Histogram class for the relative arrival time analysis. 
+//  Histogram class for the relative arrival time calibration.
 //  Holds the histogrammed arrival times,
 //  derives from MHGausEvents, perform Fourier analysis
@@ -43,6 +43,4 @@
 const Axis_t  MHCalibrationRelTimePix::fgChargeFirst    = -13.;
 const Axis_t  MHCalibrationRelTimePix::fgChargeLast     =  13.;
-
-const Int_t   MHCalibrationRelTimePix::fgPulserFrequency = 200;
 // --------------------------------------------------------------------------
 //
@@ -67,5 +65,4 @@
   fHGausHist.Sumw2();
 
-  SetPulserFrequency();
 }
 
@@ -103,10 +100,4 @@
 
 
-void  MHCalibrationRelTimePix::SetPulserFrequency(Float_t f)
-{
-  SetEventFrequency(f);
-}
-
-
 void  MHCalibrationRelTimePix::BypassFit()
 {
Index: /trunk/MagicSoft/Mars/mcalib/MHCalibrationRelTimePix.h
===================================================================
--- /trunk/MagicSoft/Mars/mcalib/MHCalibrationRelTimePix.h	(revision 3619)
+++ /trunk/MagicSoft/Mars/mcalib/MHCalibrationRelTimePix.h	(revision 3620)
@@ -11,15 +11,13 @@
 private:
 
-  static const Int_t   fgPulserFrequency;
+  static const Int_t   fgChargeNbins;      // Default for fChargeNBins  (now set to: 900   )
+  static const Axis_t  fgChargeFirst;      // Default for fChargeFirst  (now set to: -13.5 )
+  static const Axis_t  fgChargeLast;       // Default for fChargeLast   (now set to:  13.5 )
 
-  static const Int_t   fgChargeNbins;
-  static const Axis_t  fgChargeFirst;
-  static const Axis_t  fgChargeLast;
+  Int_t   fChargeNbins;                   // Number of  bins used for the fHGausHist
+  Axis_t  fChargeFirst;                   // Lower bound bin used for the fHGausHist
+  Axis_t  fChargeLast;                    // Upper bound bin used for the fHGausHist
 
-  Int_t   fChargeNbins;
-  Axis_t  fChargeFirst;
-  Axis_t  fChargeLast;
-
-  Int_t fPixId;                  // Pixel Nr
+  Int_t fPixId;                           // The pixel ID
 
 public:
@@ -36,6 +34,4 @@
   void SetChargeLast( const Axis_t last =fgChargeLast)     { fChargeLast  = last; }
 
-  void SetPulserFrequency(Float_t f=fgPulserFrequency);
-
   // Fits
   void BypassFit();
@@ -45,7 +41,5 @@
   void Renorm(const Float_t slicewidth);
   
-  //  TObject *DrawClone(Option_t *opt="") const;
-  
-  ClassDef(MHCalibrationRelTimePix, 1)     // Histograms for each calibrated pixel
+  ClassDef(MHCalibrationRelTimePix, 1)     // Histogram class for Relative Time Calibration pixel
 };
 

Index: /trunk/MagicSoft/Mars/mcalib/MHCalibrationRelTimeCam.h
===================================================================
--- /trunk/MagicSoft/Mars/mcalib/MHCalibrationRelTimeCam.h	(revision 3619)
+++ /trunk/MagicSoft/Mars/mcalib/MHCalibrationRelTimeCam.h	(revision 3620)
@@ -19,6 +19,9 @@
 private:
 
-  static const Float_t fgTimeSliceWidth;          // Default FADC slice time width for MAGIC
-  Float_t              fTimeSliceWidth;          //  FADC slice time width
+  static const Float_t fgTimeSliceWidth;       // Default for fTimeSliceWidth
+  static const Int_t   fgPulserFrequency;      // Default for fPulserFrequency
+
+  Float_t fTimeSliceWidth;                    // FADC slice time width
+  Int_t   fPulserFrequency;                   // The pulser frequency
   
   TObjArray  *fArray;       //-> List of MHCalibrationRelTimePix's
@@ -39,5 +42,6 @@
 
   // Setters
-  void SetTimeSliceWidth(const Float_t width=fgTimeSliceWidth)  {  fTimeSliceWidth = width; }
+  void SetTimeSliceWidth( const Float_t width=fgTimeSliceWidth)  {  fTimeSliceWidth = width; }
+  void SetPulserFrequency( const Int_t  f=fgPulserFrequency)     { fPulserFrequency = f;     }
   
   TObject *Clone(const char *) const;